Some help in getting started is provided in the README within the master branch base directory.  Additional documentation is available on the [wiki page](https://github.com/ageller/Firefly/wiki/Documentation) associated with this repository.
